<template>
	<div>
		<div class="h-full" v-loading="chartLoading" v-resize="chartContainerResize">
			<div ref="chartRef"></div>
		</div>
	</div>
</template>

<script setup lang="ts" name="ChartDisplay">
import { defaultsDeep, groupBy } from 'lodash-es';
import { computed, onMounted, ref, watch } from 'vue';
import { getChatChartOption, SCATTER_SYMBOL_SIZE } from '../../../chatComponents/common';
import { ChartTypeEnum } from '../../../chatComponents/types';
import { useDrawChatChart } from '/@/components/chat/chatComponents/hooks/useDrawChatChart';

const props = defineProps({
	values: {
		type: Object as any,
		default: () => {},
	},
	mapRow: {
		type: Object as any,
		default: () => {},
	},
});

const chartRef = ref<HTMLDivElement>();

const drawChart = () => {
	const columns = props?.values?.columns ?? [];
	if (columns.length === 0) return;
	const xRowTitle = columns[0];
	const yRowTitle = columns[1];
	const combineOption = defaultsDeep(
		{
			grid: {
				bottom: 20,
			},
			legend: {
				top: 19,
				show: true,
				type: 'scroll',
			},
			tooltip: {
				// valueFormatter: tooltipValueFormatter,
			},
			toolbox: {
				show: true,
				feature: {
					myBar: {
						onclick: () => {
							activeChartType = ChartTypeEnum.Bar;
							chartInstance.value.setOption({
								series: seriesInfo.value.map((item) => ({
									...item,
									...getChartTypeSeriesOption(activeChartType),
								})),
							});
						},
					},

					myScatter: {
						onclick: () => {
							activeChartType = ChartTypeEnum.Scatter;

							chartInstance.value.setOption({
								series: seriesInfo.value.map((item) => ({
									...item,
									...getChartTypeSeriesOption(activeChartType),
								})),
							});
						},
					},
					myLine: {
						onclick: () => {
							activeChartType = ChartTypeEnum.Line;
							chartInstance.value.setOption({
								series: seriesInfo.value.map((item) => ({
									...item,
									...getChartTypeSeriesOption(activeChartType),
								})),
							});
						},
					},
				},
			},

			title: {
				text: props.mapRow?.title,
			},
			xAxis: {
				name: xRowTitle,
			},
			yAxis: {
				name: yRowTitle,

				/** @description 不强制保留 */
				scale: true,
			},
			series: seriesInfo.value,
		} as echarts.EChartsOption,
		getChatChartOption()
	);
	chartInstance.value?.setOption(combineOption, {
		notMerge: true,
	});
};

const getChartTypeSeriesOption = (type: ChartTypeEnum) => {
	let result = {};
	switch (type) {
		case ChartTypeEnum.Bar:
			result = {
				type: 'bar',
				symbol: 'none',
			};

			break;
		case ChartTypeEnum.Line:
			result = {
				type: 'line',
				symbol: 'none',
				smooth: true,
			};

			break;

		case ChartTypeEnum.Scatter:
			result = {
				type: 'scatter',
				symbol: 'circle',
				symbolSize: SCATTER_SYMBOL_SIZE,
			};

			break;
		case ChartTypeEnum.Score:
			result = {
				type: 'bar',
				symbol: 'none',
			};

			break;

		default:
			break;
	}

	return result;
};
let activeChartType: ChartTypeEnum = ChartTypeEnum.Line;

const seriesInfo = computed(() => {
	const columns = props.values?.columns ?? [];
	if (columns.length === 0) return [];
	const xProp = 0;
	const yProp = 1;

	const series = [
		{
			// name: key,
			data: props.values?.records.toSorted((b, a) => {
				return b[xProp]?.localeCompare(a[xProp]);
			}),
			...getChartTypeSeriesOption(activeChartType),
		},
	];

	return series;
});

const chartLoading = ref(false);
const { chartContainerResize, chartInstance } = useDrawChatChart({ chartRef, drawChart });

watch(
	() => props.values,
	(val) => {
		drawChart();
	}
);


</script>
<style scoped lang="scss"></style>
